@@ -19,7 +19,7 @@ use Types::Standard qw/Str Int Bool HashRef/;
 use Type::Utils;
 use Module::Pluggable require => 1, search_path => ['Group::Git::Cmd', 'Group::Git::Taggers'];
 
-our $VERSION = version->new('0.6.2');
+our $VERSION = version->new('0.6.3');
 our $AUTOLOAD;
 
 has conf => (
@@ -123,14 +123,16 @@ sub _repos {
 }
 
 sub cmd {
-    my ($self, $command, $project) = @_;
+    my ($self, $type, $command, $project) = @_;
     return if !$project || !-d $project;
 
     local $CWD = $project;
     local @ARGV = @ARGV;
-    my $cmd = join ' ', 'git', map { $self->shell_quote } $command, @ARGV;
+    my $cmd = join ' ', map { $self->shell_quote }
+        grep { defined $_ && $_ ne '' }
+        $type, $command, @ARGV;
 
-    return `$cmd`;
+    return scalar `$cmd`;
 }
 
 sub shell_quote {
@@ -165,7 +167,7 @@ Group::Git - Base module for group of git repository operations.
 
 =head1 VERSION
 
-This documentation refers to Group::Git version 0.6.2.
+This documentation refers to Group::Git version 0.6.3.
 
 =head1 SYNOPSIS
 
